==> reference4-1.0-sources.jar: one/xingyi/reference4/person/client/view/PersonLine12View.java <==
package one.xingyi.reference4.person.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference4.person.IPersonLine12ViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface PersonLine12View  extends IXingYiView<one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonLine12View, T> fn){return service.get(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonLine12View, T> fn){return service.getOptional(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id,fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonLine12View > edit(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonLine12View,one.xingyi.reference4.person.client.view.PersonLine12View> fn){return service.edit(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id, fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonLine12View> create(HttpServiceCompletableFuture service, String id){return service.create(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id);}
    public static CompletableFuture<IdAndValue<one.xingyi.reference4.person.client.view.PersonLine12View>> create(HttpServiceCompletableFuture service, one.xingyi.reference4.person.client.view.PersonLine12View view){return service.createWithoutId(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion, view);}
    public static CompletableFuture<Boolean> delete(HttpServiceCompletableFuture service, String id){return service.delete(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id);}
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line1, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line1');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line1, readOnly=false, lensName=lens_Person_line1, lensPath=line1/String, javascript=function lens_Person_line1(){return lens('line1');};, templated=false, deprecated=false)]
    default public Lens<PersonLine12View,java.lang.String> line1Lens(){ return xingYi().stringLens(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion, "lens_Person_line1");}
    default public java.lang.String line1(){ return line1Lens().get(this);};
    default public PersonLine12View withline1(java.lang.String line1){ return line1Lens().set(this,line1);}
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line2, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line2');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line2, readOnly=false, lensName=lens_Person_line2, lensPath=line2/String, javascript=function lens_Person_line2(){return lens('line2');};, templated=false, deprecated=false)]
    default public Lens<PersonLine12View,java.lang.String> line2Lens(){ return xingYi().stringLens(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion, "lens_Person_line2");}
    default public java.lang.String line2(){ return line2Lens().get(this);};
    default public PersonLine12View withline2(java.lang.String line2){ return line2Lens().set(this,line2);}
}

==> reference4-1.1-sources.jar: one/xingyi/reference4/person/client/view/PersonLine12View.java <==
package one.xingyi.reference4.person.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference4.person.IPersonLine12ViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface PersonLine12View  extends IXingYiView<one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonLine12View, T> fn){return service.get(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonLine12View, T> fn){return service.getOptional(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id,fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonLine12View > edit(HttpServiceCompletableFuture service, String id, Function<one.xingyi.reference4.person.client.view.PersonLine12View,one.xingyi.reference4.person.client.view.PersonLine12View> fn){return service.edit(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id, fn);}
    public static CompletableFuture<one.xingyi.reference4.person.client.view.PersonLine12View> create(HttpServiceCompletableFuture service, String id){return service.create(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id);}
    public static CompletableFuture<IdAndValue<one.xingyi.reference4.person.client.view.PersonLine12View>> create(HttpServiceCompletableFuture service, one.xingyi.reference4.person.client.view.PersonLine12View view){return service.createWithoutId(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion, view);}
    public static CompletableFuture<Boolean> delete(HttpServiceCompletableFuture service, String id){return service.delete(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion,id);}
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=line1, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line1');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=line1, readOnly=false, lensName=lens_Person_line1, lensPath=line1/String, javascript=function lens_Person_line1(){return lens('line1');};, templated=false, deprecated=false)]
    default public Lens<PersonLine12View,java.lang.String> line1Lens(){ return xingYi().stringLens(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion, "lens_Person_line1");}
    default public java.lang.String line1(){ return line1Lens().get(this);};
    default public PersonLine12View withline1(java.lang.String line1){ return line1Lens().set(this,line1);}
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=line2, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line2');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=line2, readOnly=false, lensName=lens_Person_line2, lensPath=line2/String, javascript=function lens_Person_line2(){return lens('line2');};, templated=false, deprecated=false)]
    default public Lens<PersonLine12View,java.lang.String> line2Lens(){ return xingYi().stringLens(one.xingyi.reference4.person.client.viewcompanion.PersonLine12ViewCompanion.companion, "lens_Person_line2");}
    default public java.lang.String line2(){ return line2Lens().get(this);};
    default public PersonLine12View withline2(java.lang.String line2){ return line2Lens().set(this,line2);}
}
